@@ -79,4 +79,4 @@ def generate_froc_curve(
 
         plt.savefig(plot_output_path, dpi=50)
     else:
-        return lls, nlls
+        return lls_accuracy, nlls_accuracy
